
Example of 'autosummary' usage
==============================

see `autosummary extension page`_ for more documentation.

.. currentmodule:: {{ base.pkg_full_name }}


bla bla

.. autosummary::
   :toctree: autogen
   
   example_doc

final bla!

.. _`autosummary extension page`: http://www.sphinx-doc.org/en/stable/ext/autosummary.html
